@@ -30,10 +30,17 @@ namespace {
             const
 #endif
             SV * const, U32);
+#if PERL_VERSION >= 19
+    char *   RE2_intuit(pTHX_ REGEXP * const, SV *, const char *,
+                        char *, char *, U32, re_scream_pos_data *);
+    I32      RE2_exec(pTHX_ REGEXP * const, char *, char *,
+                      char *, SSize_t, SV *, void *, U32);
+#else
     I32      RE2_exec(pTHX_ REGEXP * const, char *, char *,
                       char *, I32, SV *, void *, U32);
     char *   RE2_intuit(pTHX_ REGEXP * const, SV *, char *,
                         char *, U32, re_scream_pos_data *);
+#endif
     SV *     RE2_checkstr(pTHX_ REGEXP * const);
     void     RE2_free(pTHX_ REGEXP * const);
     SV *     RE2_package(pTHX_ REGEXP * const);
@@ -94,13 +101,15 @@ RE2_comp(pTHX_
 #endif
         SV * const pattern, const U32 flags)
 {
-    const char *const exp = SvPVX(pattern);
-    const STRLEN plen = SvCUR(pattern);
-    U32 extflags = flags;
-
+    const char *exp;
+    STRLEN plen;
     RE2::Options options;
+
+    U32 extflags = flags;
     bool perl_only = false;
 
+    exp = SvPV(pattern, plen);
+
     /* C<split " ">, bypass the engine alltogether and act as perl does */
     if (flags & RXf_SPLIT && plen == 1 && exp[0] == ' ')
         extflags |= (RXf_SKIPWHITE|RXf_WHITE);
@@ -169,7 +178,7 @@ RE2_comp(pTHX_
             const string error = ri->error();
             delete ri;
 
-            croak(perl_only
+            croak("%s", perl_only
                     ? "/x is not supported by RE2"
                     : error.c_str());
             return NULL; // unreachable
@@ -243,10 +252,17 @@ RE2_comp(pTHX_
     return rx_sv;
 }
 
+#if PERL_VERSION >= 19
+I32
+RE2_exec(pTHX_ REGEXP * const rx, char *stringarg, char *strend,
+          char *strbeg, SSize_t minend, SV * sv,
+          void *data, U32 flags)
+#else
 I32
 RE2_exec(pTHX_ REGEXP * const rx, char *stringarg, char *strend,
           char *strbeg, I32 minend, SV * sv,
           void *data, U32 flags)
+#endif
 {
     RE2 * ri = (RE2*) RegSV(rx)->pprivate;
     regexp * re = RegSV(rx);
@@ -291,12 +307,21 @@ RE2_exec(pTHX_ REGEXP * const rx, char *stringarg, char *strend,
     return 1;
 }
 
+#if PERL_VERSION >= 19
+char *
+RE2_intuit(pTHX_ REGEXP * const rx, SV * sv, const char *strbeg, char *strpos,
+             char *strend, U32 flags, re_scream_pos_data *data)
+#else
 char *
 RE2_intuit(pTHX_ REGEXP * const rx, SV * sv, char *strpos,
              char *strend, U32 flags, re_scream_pos_data *data)
+#endif
 {
 	PERL_UNUSED_ARG(rx);
 	PERL_UNUSED_ARG(sv);
+#if PERL_VERSION >= 19
+	PERL_UNUSED_ARG(strbeg);
+#endif
 	PERL_UNUSED_ARG(strpos);
 	PERL_UNUSED_ARG(strend);
 	PERL_UNUSED_ARG(flags);
